﻿Imports Elasticsearch.Net
Imports ElasticSearchRepository
Imports Nest
Imports System.IO
Imports System.Text
Imports System.Threading.Tasks

Namespace EnterpriseSearch
	Friend Class Program
		Shared Sub Main(ByVal args() As String)

			Dim c As New ElasticClient()
			c.DeleteIndex(Function(d) d.AllIndices(True))

			Dim indexRepository = New IndexRepository()
			indexRepository.CreateMarketingIndex()

			Dim clients = GetClientsMock()
			clients.ForEach(Sub(client) indexRepository.IndexData(Of Client)(client, "clients"))


			Dim documents = GetMarketingDocumentsMock()
			documents.ForEach(Sub(document) indexRepository.IndexData(Of MarketingDocument)(document, "marketing"))
		End Sub

		''' <summary>
		''' Encodes the file as Base64 string.
		''' </summary>
		''' <param name="filePath">The file path.</param>
		''' <returns>A base64 encoded file.</returns>
		Private Shared Function EncodeFile(ByVal filePath As String) As String
			Dim fs = New FileStream(filePath, FileMode.Open, FileAccess.Read)
			Dim filebytes = New Byte(fs.Length - 1){}
			fs.Read(filebytes, 0, Convert.ToInt32(fs.Length))
			Dim encodedData = Convert.ToBase64String(filebytes, Base64FormattingOptions.InsertLineBreaks)

			Return encodedData
		End Function

		Private Shared Function GetClientsMock() As List(Of Client)
			Return New List(Of Client)() From {New Client() With {.Id = 1, .Name="Jack", .Surname="Black", .Email="john.black@scrummers.com", .Company = "Scrum"}, New Client() With {.Id = 2, .Name="Jack", .Surname="White", .Email="jwhite@externals.com", .Company = "Externals"}}
		End Function


		''' <summary>
		'''  A mock for getting a marketing products documents from neetwork share.
		''' </summary>
		''' <returns>A list of marketing documents.</returns>
		Private Shared Function GetMarketingDocumentsMock() As List(Of MarketingDocument)
			Const scrumTutorialFilePath As String = "C:\Scrum guidelines.pdf"
			Const csharpTutorialFilePath As String = "C:\csharp.pdf"

			Return New List(Of MarketingDocument)() From {New MarketingDocument() With {.Id = 1, .ProductName = "Scrum interactive tutorial", .Name = "A scrum tutorial", .Document = EncodeFile(scrumTutorialFilePath)}, New MarketingDocument() With {.Id = 2, .ProductName = "C# tutorial", .Name = "A .NET C# tutorial and repicpes", .Document = EncodeFile(csharpTutorialFilePath)}}
		End Function
	End Class
End Namespace

